@@ -1,7 +1,7 @@
 /*
  * ipv6calc	This program print out different formats of an given IPv6 address
  *
- * Version:     $Id: ipv6calc.c,v 0.13 2001/03/10 $
+ * Version:     $Id: ipv6calc.c,v 0.15 2001/03/12 $
  * 
  * Author:      Peter Bieringer <pb@bieringer.de>
  * 
@@ -38,6 +38,7 @@ void printhelp() {
 	ifinet6_to_compressed_printhelp();
 	addr_to_base85_printhelp();
 	base85_to_addr_printhelp();
+	mac_to_eui64_printhelp();
 
 	return;
 };
@@ -48,7 +49,7 @@ void printhelp() {
 int main(int argc,char *argv[]) {
 	char resultstring[NI_MAXHOST];
 	int retval = 1, i, lop;
-	unsigned int command = 0;
+	unsigned long int command = 0;
 
 	/* defined options */
 	char *shortopts = "vh?r";
@@ -62,8 +63,12 @@ int main(int argc,char *argv[]) {
 		{"addr_to_compressed", 0, 0, CMD_addr_to_compressed},
 		{"addr2uncompaddr", 0, 0, CMD_addr_to_uncompressed},
 		{"addr_to_uncompressed", 0, 0, CMD_addr_to_uncompressed},
+		
 		{"addr_to_base85", 0, 0, CMD_addr_to_base85},
 		{"base85_to_addr", 0, 0, CMD_base85_to_addr},
+
+		{"mac_to_eui64", 0, 0, CMD_mac_to_eui64},
+		
 		{"addr2fulluncompaddr", 0, 0, CMD_addr_to_fulluncompressed},
 		{"addr_to_fulluncompressed", 0, 0, CMD_addr_to_fulluncompressed},
 		{"addr2if_inet6", 0, 0, CMD_addr_to_ifinet6},
@@ -104,12 +109,18 @@ int main(int argc,char *argv[]) {
 			case CMD_addr_to_uncompressed:
 				command |= CMD_addr_to_uncompressed;
 				break;
+				
 			case CMD_addr_to_base85:
 				command |= CMD_addr_to_base85;
 				break;
 			case CMD_base85_to_addr:
 				command |= CMD_base85_to_addr;
 				break;
+
+			case CMD_mac_to_eui64:
+				command |= CMD_mac_to_eui64;
+				break;
+				
 			case CMD_addr_to_fulluncompressed:
 				command |= CMD_addr_to_fulluncompressed;
 				break;
@@ -140,7 +151,7 @@ int main(int argc,char *argv[]) {
 	argv += optind;
 	argc -= optind;
 
-/*	fprintf(stderr, "Command value: %x\n", command); */
+//	fprintf(stderr, "Command value: %lx\n", command); 
 	
 	/* do work depending on selection */
 	if (command & CMD_printversion) {
@@ -216,6 +227,19 @@ int main(int argc,char *argv[]) {
 				retval = base85_to_addr(argv[0], resultstring);
 				fprintf(stdout, "%s\n", resultstring);
 				break;
+				
+			case CMD_mac_to_eui64:
+				if ((argc < 1) || (command & CMD_printhelp)) {
+					if ((argc < 1) && ! (command & CMD_printhelp)) {
+						fprintf(stderr, "missing argument!\n\n");
+					};
+					mac_to_eui64_printhelplong();
+					exit(1);
+				};
+				retval = mac_to_eui64(argv[0], resultstring);
+				fprintf(stdout, "%s\n", resultstring);
+				break;
+				
 			case CMD_addr_to_ifinet6:
 				if ((argc < 1) || (command & CMD_printhelp)) {
 					if ((argc < 1) && ! (command & CMD_printhelp)) {
